@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "artbollocks-mode" "1.2.0"
+(define-package "artbollocks-mode" "20251211.1624"
   "Improve your writing (especially about art)."
   '((emacs "25.1"))
   :url "https://github.com/sachac/artbollocks-mode"
